<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr">
<context>
    <name>LXQtWorldClock</name>
    <message>
        <location filename="../lxqtworldclock.cpp" line="245"/>
        <source>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</source>
        <translation>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd,d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</translation>
    </message>
</context>
<context>
    <name>LXQtWorldClockConfiguration</name>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="14"/>
        <source>World Clock Settings</source>
        <translation>Подешавања светског сата</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="24"/>
        <source>Display &amp;format</source>
        <translation>Прикажи &amp;формат</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="30"/>
        <source>&amp;Time</source>
        <translation>&amp;Време</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="39"/>
        <source>F&amp;ormat:</source>
        <translation>Ф&amp;ормат:</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="50"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="176"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="272"/>
        <source>Short</source>
        <translation>Кратко</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="55"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="181"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="277"/>
        <source>Long</source>
        <translation>Дугачко</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="60"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="287"/>
        <source>Custom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="89"/>
        <source>Sho&amp;w seconds</source>
        <translation>Прика&amp;жи секунде</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="96"/>
        <source>Pad &amp;hour with zero</source>
        <translation>Постави &amp;сат са нулом</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="116"/>
        <source>T&amp;ime zone</source>
        <translation>В&amp;ременска зона</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="128"/>
        <source>&amp;Position:</source>
        <translation>&amp;Позиција:</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="138"/>
        <source>For&amp;mat:</source>
        <translation>Фор&amp;мат:</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="149"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="238"/>
        <source>Below</source>
        <translation>Испод</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="154"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="243"/>
        <source>Above</source>
        <translation>Изнад</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="159"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="248"/>
        <source>Before</source>
        <translation>Пре</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="164"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="253"/>
        <source>After</source>
        <translation>После</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="186"/>
        <source>Offset from UTC</source>
        <translation>Помак од UTC</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="191"/>
        <source>Abbreviation</source>
        <translation>Скраћеница</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="431"/>
        <source>IANA id</source>
        <translation>IANA id</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="201"/>
        <location filename="../lxqtworldclockconfiguration.ui" line="436"/>
        <location filename="../lxqtworldclockconfiguration.cpp" line="585"/>
        <source>Custom name</source>
        <translation>Прилагођено име</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="103"/>
        <source>&amp;Use 12-hour format</source>
        <translation>&amp;Користи 12-о часовни формат</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="196"/>
        <source>Location identifier</source>
        <translation>Идентификатор локације</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="212"/>
        <source>&amp;Date</source>
        <translation>&amp;Датум</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="227"/>
        <source>Po&amp;sition:</source>
        <translation>По&amp;зиција:</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="261"/>
        <source>Fo&amp;rmat:</source>
        <translation>Фо&amp;рмат:</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="282"/>
        <source>ISO 8601</source>
        <translation>ISO 8601</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="316"/>
        <source>Show &amp;year</source>
        <translation>Прикажи &amp;годину</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="323"/>
        <source>Show day of wee&amp;k</source>
        <translation>Прикажи дан седмиц&amp;е</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="330"/>
        <source>Pad d&amp;ay with zero</source>
        <translation>Постави д&amp;ан са нулом</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="337"/>
        <source>&amp;Long month and day of week names</source>
        <translation>&amp;Дуги називи месеци и дана седмице</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="350"/>
        <source>Ad&amp;vanced manual format</source>
        <translation>На&amp;предни ручни формат</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="377"/>
        <source>&amp;Customize ...</source>
        <translation>&amp;Прилагоди ...</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="403"/>
        <source>Time &amp;zones</source>
        <translation>Временске &amp;зоне</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="446"/>
        <source>&amp;Add ...</source>
        <translation>&amp;Додај ...</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="456"/>
        <source>&amp;Remove</source>
        <translation>&amp;Уклони</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="466"/>
        <source>Set as &amp;default</source>
        <translation>Постави као &amp;подразумевано</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="476"/>
        <source>&amp;Edit custom name ...</source>
        <translation>&amp;Измени прилагођено име ...</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="486"/>
        <source>Move &amp;up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="496"/>
        <source>Move do&amp;wn</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="518"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; Middle-click the clock to view the time and date for all configured timezones.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="529"/>
        <source>&amp;General</source>
        <translation>&amp;Опште</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="535"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation>Ауто&amp;ротирај када је панел вертикалан</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="545"/>
        <source>Show &amp;week numbers in popup calendar</source>
        <translation>Прикажи &amp;бројеве седмица у искачућем календару</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.ui" line="555"/>
        <source>S&amp;how tooltip</source>
        <translation>П&amp;рикажи поруку</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.cpp" line="106"/>
        <source>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</source>
        <translation>&apos;&lt;b&gt;&apos;HH:mm:ss&apos;&lt;/b&gt;&lt;br/&gt;&lt;font size=&quot;-2&quot;&gt;&apos;ddd, d MMM yyyy&apos;&lt;br/&gt;&apos;TT&apos;&lt;/font&gt;&apos;</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfiguration.cpp" line="584"/>
        <source>Input custom time zone name</source>
        <translation>Унеси прилагођено име временске зоне</translation>
    </message>
</context>
<context>
    <name>LXQtWorldClockConfigurationManualFormat</name>
    <message>
        <location filename="../lxqtworldclockconfigurationmanualformat.ui" line="14"/>
        <source>World Clock Manual Format Configuration</source>
        <translation>Конфигурација ручног формата светског сата</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationmanualformat.ui" line="83"/>
        <source>&lt;h1&gt;Custom Date/Time Format Syntax&lt;/h1&gt;
&lt;p&gt;A date pattern is a string of characters, where specific strings of characters are replaced with date and time data from a calendar when formatting or used to generate data for a calendar when parsing.&lt;/p&gt;
&lt;p&gt;The Date Field Symbol Table below contains the characters used in patterns to show the appropriate formats for a given locale, such as yyyy for the year. Characters may be used multiple times. For example, if y is used for the year, &apos;yy&apos; might produce &apos;99&apos;, whereas &apos;yyyy&apos; produces &apos;1999&apos;. For most numerical fields, the number of characters specifies the field width. For example, if h is the hour, &apos;h&apos; might produce &apos;5&apos;, but &apos;hh&apos; produces &apos;05&apos;. For some characters, the count specifies whether an abbreviated or full form should be used, but may have other choices, as given below.&lt;/p&gt;
&lt;p&gt;Two single quotes represents a literal single quote, either inside or outside single quotes. Text within single quotes is not interpreted in any way (except for two adjacent single quotes). Otherwise all ASCII letter from a to z and A to Z are reserved as syntax characters, and require quoting if they are to represent literal characters. In addition, certain ASCII punctuation characters may become variable in the future (eg &quot;:&quot; being interpreted as the time separator and &apos;/&apos; as a date separator, and replaced by respective locale-sensitive characters in display).&lt;br /&gt;&lt;/p&gt;
&lt;table border=&quot;1&quot; width=&quot;100%&quot; cellpadding=&quot;4&quot; cellspacing=&quot;0&quot;&gt;
&lt;tr&gt;&lt;th width=&quot;20%&quot;&gt;Code&lt;/th&gt;&lt;th&gt;Meaning&lt;/th&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;d&lt;/td&gt;&lt;td&gt;the day as number without a leading zero (1 to 31)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;dd&lt;/td&gt;&lt;td&gt;the day as number with a leading zero (01 to 31)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ddd&lt;/td&gt;&lt;td&gt;the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;dddd&lt;/td&gt;&lt;td&gt;the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;M&lt;/td&gt;&lt;td&gt;the month as number without a leading zero (1-12)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MM&lt;/td&gt;&lt;td&gt;the month as number with a leading zero (01-12)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MMM&lt;/td&gt;&lt;td&gt;the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MMMM&lt;/td&gt;&lt;td&gt;the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;yy&lt;/td&gt;&lt;td&gt;the year as two digit number (00-99)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;yyyy&lt;/td&gt;&lt;td&gt;the year as four digit number&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;h&lt;/td&gt;&lt;td&gt;the hour without a leading zero (0 to 23 or 1 to 12 if AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;hh&lt;/td&gt;&lt;td&gt;the hour with a leading zero (00 to 23 or 01 to 12 if AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;H&lt;/td&gt;&lt;td&gt;the hour without a leading zero (0 to 23, even with AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;HH&lt;/td&gt;&lt;td&gt;the hour with a leading zero (00 to 23, even with AM/PM display)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;m&lt;/td&gt;&lt;td&gt;the minute without a leading zero (0 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;mm&lt;/td&gt;&lt;td&gt;the minute with a leading zero (00 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;s&lt;/td&gt;&lt;td&gt;the second without a leading zero (0 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ss&lt;/td&gt;&lt;td&gt;the second with a leading zero (00 to 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;AP &lt;i&gt;or&lt;/i&gt; A&lt;/td&gt;&lt;td&gt;use AM/PM display. &lt;b&gt;A/AP&lt;/b&gt; will be replaced by either &quot;AM&quot; or &quot;PM&quot;.&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ap &lt;i&gt;or&lt;/i&gt; a&lt;/td&gt;&lt;td&gt;use am/pm display. &lt;b&gt;a/ap&lt;/b&gt; will be replaced by either &quot;am&quot; or &quot;pm&quot;.&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;t&lt;/td&gt;&lt;td&gt;the timezone (e.g. &quot;CEST&quot;)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;T&lt;/td&gt;&lt;td&gt;the offset from UTC&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TT&lt;/td&gt;&lt;td&gt;the timezone IANA id&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTT&lt;/td&gt;&lt;td&gt;the timezone abbreviation&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTT&lt;/td&gt;&lt;td&gt;the timezone short display name&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTTT&lt;/td&gt;&lt;td&gt;the timezone long display name&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTTTT&lt;/td&gt;&lt;td&gt;the timezone custom name. You can change it the &apos;Time zones&apos; tab of the configuration window&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;
&lt;br /&gt;&lt;b&gt;Notes:&lt;/b&gt; &lt;ul&gt;&lt;li&gt;Any characters in the pattern that are not in the ranges of [&apos;a&apos;..&apos;z&apos;] and [&apos;A&apos;..&apos;Z&apos;] will be treated as quoted text. For instance, characters like &apos;:&apos;, &apos;.&apos;, &apos; &apos;, &apos;#&apos; and &apos;@&apos; will appear in the resulting time text even they are not enclosed within single quotes. The single quote is used to &apos;escape&apos; letters. Two single quotes in a row, whether inside or outside a quoted sequence, represent a &apos;real&apos; single quote.&lt;/li&gt;&lt;li&gt;Minimal update interval is 1 second. If z or zzz is configured time is shown with the milliseconds fraction, but not updated on millisecond basis (avoiding big performance hit).&lt;/li&gt;&lt;ul&gt;
</source>
        <translation>&lt;h1&gt;Прилагођено време/Синтакса временског формата&lt;/h1&gt;
&lt;p&gt;Образац датума је низ знакова, где се одређени низови знакова замењују подацима о датуму и времену из календара приликом форматирања или се користе за генерисање података за календар приликом рашчлањивања.&lt;/p&gt;
&lt;p&gt;Табела са симболима поља датума у наставку садржи знакове који се користе у обрасцима за приказивање одговарајућих формата за дати локал, као што је yyyy за годину. Знакови се могу користити више пута. На пример, ако се и користи за годину, &apos;yy&apos; може произвести &apos;99&apos;, док &apos;yyyy&apos; производи &apos;1999&apos;. За већину нумеричких поља, број знакова одређује ширину поља. На пример, ако је h сат, &apos;h&apos; може произвести &apos;5&apos;, али &apos;hh&apos; производи &apos;05&apos;. За неке знакове, број одређује да ли треба користити скраћени или пуни образац, али може имати и друге могућности, као што је дато у наставку.&lt;/п&gt;
&lt;p&gt;Два појединачна наводника представљају дословни појединачни наводник, унутар или изван једноструких наводника. Текст унутар појединачних наводника се не тумачи ни на који начин (осим два суседна једнострука наводника). У супротном, сва ASCII слова од а до з и од А до З су резервисана као знакови синтаксе и захтевају навођење ако желе да представљају литералне знакове. Поред тога, одређени ASCII знакови интерпункције могу постати променљиви у будућности (нпр. &quot;:&quot; се тумачи као сепаратор времена и &apos;/&apos; као сепаратор датума и замењен одговарајућим знаковима осетљивим на локализацију на екрану).&lt;br /&gt;&lt;/p&gt;
&lt;table border=&quot;1&quot; width=&quot;100%&quot; cellpadding=&quot;4&quot; cellspacing=&quot;0&quot;&gt;
&lt;tr&gt;&lt;th width=&quot;20%&quot;&gt;Код&lt;/th&gt;&lt;th&gt;Значење&lt;/th&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;d&lt;/td&gt;&lt;td&gt;дан као број без нуле (1 до 31)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;dd&lt;/td&gt;&lt;td&gt;дан као број са нулом (01 до 31)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ddd&lt;/td&gt;&lt;td&gt;сраћено локализовано име дана (Нпр. &apos;Mon&apos; до &apos;Sun&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;dddd&lt;/td&gt;&lt;td&gt;дугачко локализивано име дана (нпр &apos;Monday&apos; до &apos;Sunday).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;M&lt;/td&gt;&lt;td&gt;месец без нуле (1-12)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MM&lt;/td&gt;&lt;td&gt;месец са нулом (01-12)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MMM&lt;/td&gt;&lt;td&gt;скраћено локализовано име месеца (нпр. &apos;Jan&apos; до &apos;Dec&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;MMMM&lt;/td&gt;&lt;td&gt;дугачко локализовано име месеца (нпр. &apos;January&apos; до &apos;December&apos;).&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;yy&lt;/td&gt;&lt;td&gt;година као две цифре (00-99)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;yyyy&lt;/td&gt;&lt;td&gt;година као четвороцифрени број&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;h&lt;/td&gt;&lt;td&gt;сат без нуле (0 до 23 или 1 до 12 ако се AM/PM приказују)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;hh&lt;/td&gt;&lt;td&gt;сат са нулом (00 до 23 или 01 до 12 ако се AM/PM приказују)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;H&lt;/td&gt;&lt;td&gt;сат са нулом (0 до 23, иако се AM/PM приказују)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;HH&lt;/td&gt;&lt;td&gt;сат без нзле (00 до 23, иако се AM/PM приказује)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;m&lt;/td&gt;&lt;td&gt;минут без нуле (0 до 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;mm&lt;/td&gt;&lt;td&gt;минута са нулом (00 до 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;s&lt;/td&gt;&lt;td&gt;секунда без нуле (0 до 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ss&lt;/td&gt;&lt;td&gt;секунда са нулом (00 до 59)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;AP &lt;i&gt;или&lt;/i&gt; A&lt;/td&gt;&lt;td&gt;користи AM/PM приказ. &lt;b&gt;A/AP&lt;/b&gt; ће бити замењен или са &quot;AM&quot; или са &quot;PM&quot;.&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;ap &lt;i&gt;or&lt;/i&gt; a&lt;/td&gt;&lt;td&gt;use am/pm display. &lt;b&gt;a/ap&lt;/b&gt; will be replaced by either &quot;am&quot; or &quot;pm&quot;.&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;t&lt;/td&gt;&lt;td&gt;временска зона (нпр. &quot;CEST&quot;)&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;T&lt;/td&gt;&lt;td&gt;помак од UTC&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TT&lt;/td&gt;&lt;td&gt;временска зона IANA id&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTT&lt;/td&gt;&lt;td&gt;скраћеница временске зоне&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTT&lt;/td&gt;&lt;td&gt;приказивање скраћеног имена временске зоне&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTTT&lt;/td&gt;&lt;td&gt;приказивање дугог имена временске зоне&lt;/td&gt;&lt;/tr&gt;
&lt;tr&gt;&lt;td&gt;TTTTTT&lt;/td&gt;&lt;td&gt;прилагоди име временске зоне. Можеш променити име у &apos;Time zones&apos; картици конфигурацијског прозора&lt;/td&gt;&lt;/tr&gt;&lt;/table&gt;
&lt;br /&gt;&lt;b&gt;Напомене:&lt;/b&gt; &lt;ul&gt;&lt;li&gt;Сви знакови у обрасцу који нису у опсезима [&apos;а&apos;..&apos;з&apos;] и [&apos;А&apos;..&apos;З&apos;] биће третирани као цитирани текст. На пример, знакови као што су &apos;:&apos;, &apos;.&apos;, &apos; &apos;, &apos;#&apos; и &apos;@&apos; ће се појавити у резултујућем временском тексту чак и ако нису затворени у једноструким наводницима. Једноструки наводник се користи за „избегавање“ слова. Два појединачна наводника у низу, без обзира да ли се налазе унутар или изван цитираног низа, представљају &apos;прави&apos; појединачни наводник.&lt;/li&gt;&lt;li&gt;Минимални интервал ажурирања је 1 секунда. Ако је конфигурисано z или zzzz време се приказује у милисекундама, али се не ажурира на бази милисекунди (избегавајући велики учинак).&lt;/li&gt;&lt;ul&gt;
</translation>
    </message>
</context>
<context>
    <name>LXQtWorldClockConfigurationTimeZones</name>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="14"/>
        <source>World Clock Time Zones</source>
        <translation>Временске зоне светског сата</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="36"/>
        <source>Time zone</source>
        <translation>Временска зона</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="41"/>
        <source>Name</source>
        <translation>Име</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="46"/>
        <source>Comment</source>
        <translation>Коментар</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.ui" line="51"/>
        <source>Country</source>
        <translation>Држава</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="117"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="120"/>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="128"/>
        <source>Other</source>
        <translation>Остало</translation>
    </message>
    <message>
        <location filename="../lxqtworldclockconfigurationtimezones.cpp" line="129"/>
        <source>Local timezone</source>
        <translation>Локална временска зона</translation>
    </message>
</context>
</TS>
